Mercedes-Benz ML 500 4 Matic | BRC Autocentrs

- 236
- Pēdējoreiz atjaunots 1 d.

# Mercedes-Benz ML 500

## 4 Matic (Nr: 88)

- Rīgā
- 253770 km
- 2007 g.
- 5.5l Benzīns

Cena
€ 9000
PVN nav piemērojams
Līzinga ikmēneša maksājums
€ 139
€ mēn.

###### Kārlis Kamarūts

- +371 292 16 430
- karlis.kamaruts@brc.lv

Fiziska persona
JURIDISKA PERSONA
Automašīnu maiņa
Transporta līdzeklis atrodas

### Kārlis Kamarūts

+371 292 16 430

karlis.kamaruts@brc.lv

## Mercedes-Benz ML 500

## 4 Matic

Vispārīga informācija

- 2007 g.
- 253770 km
- 5.5l Benzīns
- Automātiskā
- 285 Kw (388 HP)
- Pilnpiedziņas
- Apvidus
- 5

Virsbūves nr: WDC1641721A343529

Komplektācija
Audio, Video, Komunikācijas
Komforta aprīkojums
Salons
Gaismas
Apvidus
Cits aprīkojums
Drošības un pretzagļu iekārtas
Sēdvietas
Riepas un Diski
Līzings Mainīt SAZINIETIES

Informējam, ka www.lv.brcauto.eu interneta vietnes darbības nodrošināšanai un lietotāju apmeklētāju statistikas apkopošanai izvieto sīkdatnes, sīkāka informācija par izvietotajām sīkdatnēm un darbībām, kā atspējot sīkdatnes pieejama BRC Auto Sīkdatņu politikā.
Sīkdatņu politika

Esmu informēts/-a